# Portal NCC

O principal objetivo do Portal NCC é automatizar atividades ligadas a
administração de rede no NCC por meio de software Web.
Como objetivos específicos, tem-se:

- Atender demandas de administração e necessidades de usuários ligadas aos serviços prestados pelo NCC.
- Automatizar atividades de administração da rede antes feitas com direta intervenção de um membro (professor, servidor ou bolsista) do NCC.
- Oferecer serviços antes não ofertados aos usuários do NCC, além de facilitar os serviços já prestados (acesso a rede, usuário local, email, etc).
- Unificar atividades de gerência de rede e requisições de usuários.
- O Portal NCC foi desenvolvido utilizando a linguagem de programação Python e o framework Web Django.

## Instalação
O Portal NCC depende de  bibliotecas básicas relacionadas ao Python e Django, mas para executar em um servidor é necessário uma série de configurações. Para instalar em um sistema Debian, inicialmente precisa-se instalar o interpretador para Python3, gerenciador de pacotes do Python (pip), servidor web Apache e o módulo adicional para executar a interface de porta de entrada do servidor web (WSGI):

```bash
apt-get install python3 python3-pip apache2 libapache2-mod-wsgi-py3
```

### Configurando o Projeto


Opcionalmente, criou-se um ambiente virtual para evitar problemas de versão incompatível caso o servidor venha a se atualizar. O pacote virtualenv pode ser adquirido dentro dos pacotes do Python. Para instalar, criar e acessar o ambiente, deve-se executar:

```
pip3 install virtualenv
virtualenv ambientevirtual
source ambientevirtual/bin/activate
```
O Portal foi implementado com a versão 1.9 do Django. Além disso, utilizou-se duas bibliotecas para integrar o LDAP: ldap3 versão 2.2.3 e django-auth-ldap3-ad versão 1.5.0, que é a biblioteca para autenticar o usuário do LDAP dentro do Django. Os três pertencem aos pacotes do Python e para instalar executa-se dentro do ambiente virtual:

```
pip3 install django==1.9 ldap3==2.2.3
pip3 install django-auth-ldap3-ad==1.5.0
```

Depois disso, pode-se configurar o projeto. Dentro da pasta do Portal existe o arquivo ``settings.py'' que contém configurações, entre elas as que precisam ser alteradas para executar no servidor:
- ALLOWED_HOSTS: Uma lista de strings que representam os nomes de host / domínio que este site do Django pode servir.
- AUTHENTICATION_BACKENDS: deve-se configurar este atributo para o Django autenticar com o LDAP,  e mais alguns atributos para acesso ao LDAP como host, senha, grupos, superusuarios, etc. Todos atributos encontram-se na documentação da biblioteca django-auth-ldap3-ad 1.5.0.

Ainda dentro da pasta do projeto onde está o arquivo ''manage.py'', é necessário sincronizar o banco de dados, arquivos estáticos e mudar as permissões, executando:
```
python3 manage.py makemigrations
python3 manage.py migrate
python3 manage.py collectstatic
chmod -R 664 ~/portalncc/db.sqlite3
chmod -R 775 ~/portalncc
chown -R :www-data ~/portalncc
```

### Configuração do Apache

Para qualquer tipo de protocolo, a configuração do Apache no arquivo `.conf` dentro da tag `VirtualHost` deve ser feita da seguinte forma, tanto para HTTP ou HTTPS:
```
  Alias /static /home/usuario/portalncc/static
  <Directory /home/usuario/portalncc/static>
      Require all granted
  </Directory>

  <Directory /home/usuario/portalncc/ncc>
      <Files wsgi.py>
          Require all granted
      </Files>
  </Directory>

  WSGIDaemonProcess myproject python-home=/home/usuario/portalncc/ambientevirtual python-path=/home/usuario/portalncc
  WSGIProcessGroup myproject
  WSGIScriptAlias / /home/usuario/portalncc/ncc/wsgi.py
```
Para conferir se a sintaxe da confirmação está correta, deve-se executar o configtest e deve aparecer: `Syntax OK`. Caso esteja com a configuração correta, deve-se reiniciar o Apache:
```
apache2ctl configtest
systemctl restart apache2
```
